import numpy as np

def hyperbola( x, p ):
	a = p['a']
	Kd = p['Kd']
	c = p['c']
	return a * x / ( Kd + x ) + c;

def mm( x, p ):
	kcat = p['kcat']
	Km = p['Km']
	return kcat * x / ( Km + x );

def mm_alt( x, p ):
	kon = p['kon']
	kcat = p['kcat']
	return kon * x / ( 1.0 + kon * x / kcat );

def quadratic( x, p ):
	#Quadratic: y(t) = a * quadratic(Kd,E0,t) + c 
	#where quadratic = ((Kd+E0+t) - sqrt((Kd+E0+t)^2 - 4*E0*t)) / (2*E0)
	a = p['a']
	E = p['E']
	Kd = p['Kd']
	c = p['c']
	KES = Kd + E + x
	radicand = KES*KES - 4.0*E*x
	sqrt_rad = np.sqrt(radicand)
	theta = (KES - sqrt_rad) / (2.0 * E);
	return a * theta + c;

def bind2( x, p ):
	a = p['a']
	k1 = p['k1']
	k2 = p['k2']
	c = p['c']
	return a * (k1*x + k1*k2*x*x) / (1 + 2.0*k1*x + k1*k2*x*x) + c		

def bind3( x, p ):
	a = p['a']
	k1 = p['k1']
	k2 = p['k2']
	k3 = p['k3']
	c = p['c']
	return a * (k1*x + 2*k1*k2*x*x + k1*k2*k3*x*x*x) / (1 + 3*k1*x + 3*k1*k2*x*x + k1*k2*k3*x*x*x) + c

def bind4( x, p ):
	a = p['a']
	k1 = p['k1']
	k2 = p['k2']
	k3 = p['k3']
	k4 = p['k4']
	c = p['c']
	x2 = x*x
	x3 = x2*x
	x4 = x3*x
	k1k2 = k1*k2
	k1k2k3 = k1k2 * k3
	k1k2k3k4 = k1k2k3 * k4
	return a * (k1*x + 3*k1k2*x2 + 3*k1k2k3*x3 + k1k2k3k4*x4) / (1 + 4*k1*x + 6*k1k2*x2 + 4*k1k2k3*x3 + k1k2k3k4*x4) + c

def addNoise( x, stddev ):
	return np.random.normal( loc=x, scale=stddev )


#
# Main - edit the values in the param 'p' to generate different data.
#

t = np.linspace( 0, 500, 100 )

# hyperbola
p = { 'a': 2, 'Kd': 5, 'c': 1.5 }
y = hyperbola( t, p )
data = np.stack( (t, y), axis=-1 )
np.savetxt( "/tmp/hyperbola.txt", data, delimiter='\t', header=str(p)+'\nTime\tS1' )

# michaelis-menten
p = { 'kcat': 2, 'Km': 5 }
y = mm( t, p )
data = np.stack( (t, y), axis=-1 )
np.savetxt( "/tmp/mm.txt", data, delimiter='\t', header=str(p)+'\nTime\tS1' )

# michaelis-menten alternative
p = { 'kon': 2, 'kcat': 5 }
y = mm_alt( t, p )
data = np.stack( (t, y), axis=-1 )
np.savetxt( "/tmp/mm_alt.txt", data, delimiter='\t', header=str(p)+'\nTime\tS1' )


# quadratic
p = { 'a': 2, 'E': 5, 'Kd': 3, 'c': 1.5 }
y = quadratic( t, p )
#y = addNoise( y, .01 )
data = np.stack( (t, y), axis=-1 )
np.savetxt( "/tmp/quadratic.txt", data, delimiter='\t', header=str(p)+'\nTime\tS1' )


# 2-site
p = { 'a': 2, 'k1': .1, 'k2': .0166667, 'c': 0.5 }
y = bind2( t, p )
data = np.stack( (t, y), axis=-1 )
np.savetxt( "/tmp/bind_2site.txt", data, delimiter='\t', header=str(p)+'\nTime\tS1' )

# 3-site
p = { 'a': 2, 'k1': .1, 'k2': .0166667, 'k3': 0.5,  'c': 0.5 }
y = bind3( t, p )
data = np.stack( (t, y), axis=-1 )
np.savetxt( "/tmp/bind_3site.txt", data, delimiter='\t', header=str(p)+'\nTime\tS1' )

# 4-site
t = np.linspace( 0, 40, 200 )
p = { 'a': 1, 'k1': .0552, 'k2': .0285, 'k3': 0.0133, 'k4': 1.98, 'c': 0 }
y = bind4( t, p )
data = np.stack( (t, y), axis=-1 )
np.savetxt( "/tmp/bind_4site.txt", data, delimiter='\t', header=str(p)+'\nTime\tS1' )
