import numpy as np
import scipy.stats
import matplotlib.mlab as mlab
import matplotlib.pyplot as plt


def norm1000():
  s = np.random.standard_normal( 10000 )
  n,bins,patches = plt.hist(s,50)
  plt.axis( [ -5,5,0,700 ] )
  plt.show()


def chidist( dof ):
  s = np.random.standard_normal( size=(dof,100000 ) )
  ssq = np.sum( s**2 / dof, axis=0 )

  n,bins,patches = plt.hist(ssq,100)

  plt.show()


def fdist_percentile( cumulative_p, dof1, dof2 ):
  return scipy.stats.f.isf( 1.0-cumulative_p, dof1, dof2 )


def fdist_percentile_norm( cumulative_p, dof1, dof2 ):
  f = scipy.stats.f.isf( 1.0-cumulative_p, dof1, dof2 )
  return 1.0 + float(dof1) * f / float(dof2)

def fdist_vals_for_params( cumulative_p, dof1 ):
  #
  # I want to see how the critical value, or percentile, or whatever that value is called,
  # changes as the dof2 goes up for a given cumulative_p

  x = np.arange( 5,500 )
  
  vfunc = np.vectorize( fdist_percentile )

  y = vfunc( cumulative_p, dof1, x )

  vfunc2 = np.vectorize( fdist_percentile_norm )

  z = vfunc2( cumulative_p, dof1, x )

  alpha = 1 - cumulative_p


  plt.plot( x, y, 'b--', label='F(P,N-P,'+str(alpha)+')' )
  plt.plot( x, z, 'r--', label='1+P/(N-P)*F(P,N-P,'+str(alpha)+')' )
  plt.xlabel( 'N-P, (P=4)')
  plt.title( r'$1-\alpha$' + " = " + str(cumulative_p) + "%" )

  plt.ylim( [ 1, 3 ] )

  legend = plt.legend( loc='best', shadow=None )

  plt.show()
  

  return x,y,z

def histNormed( bins, mu, sigma ):
  #
  # This histogram is normalized such that the integral of the histogram is 1,
  # just like the normpdf curve that is displayed with it.  The probability
  # of an obsersavtion falling into a bin is the *area* of the bin.
  #
  x = mu + sigma*np.random.randn(10000)

  # the histogram of the data
  n, bins, patches = plt.hist(x, bins, normed=1, facecolor='green', alpha=0.75)

  # add a 'best fit' line
  domain = np.linspace( np.amin(x), np.amax(x), 100 )
  y = mlab.normpdf( domain, mu, sigma)
  l = plt.plot(domain, y, 'r--', linewidth=1)

  plt.xlabel('Value')
  plt.ylabel('Probability')
  plt.grid(True)

  plt.show()


def histFraction( bins, mu, sigma ):
  #
  # This histogram is scaled such that the y-axis tells you the probability 
  # of an observation falling into a bin.  
  #
  x = mu + sigma*np.random.randn(10000)

  # the histogram of the data.  We used weights to cause the sum for all bins
  # to add up to 1, so that the height of the bin is the fraction of observations
  # taht fall into that bin.
  w = np.zeros_like( x ) + 1.0 / len(x)
  n, bins, patches = plt.hist(x, bins, weights=w, facecolor='green', alpha=0.75)

  # add a 'best fit' line, and scale this so that the integral over the distribution
  # is the same as the integral over the histogram.  Since we've weighted the histogram
  # to produce fractional observations, the total height of the hist is already 1.
  dx = bins[1] - bins[0]
  integral_hist = dx 

  domain = np.linspace( np.amin(x), np.amax(x), 100 )
  y = mlab.normpdf( domain, mu, sigma)
  l = plt.plot(domain, y * integral_hist, 'r--', linewidth=1)

  plt.xlabel('Value')
  plt.ylabel('Frequency (Fraction)')
  plt.grid(True)

  plt.show()


